<?php

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}


class ALS_Lite {

    /**
     * @var       Plugin version
     * @since       2.1.1
     */
     public $version = '2.3.3';

     /**
     * @var       Plugin instance
     * @since       2.1.1
     */
    private static $instance = null;

    /**
     * @var       Plugin path
     * @since       2.1.1
     */
    public $includes_path = null;

    /**
    * @var       Plugin url
    * @since       2.1.1
    */
    public $includes_url = null;

    /**
    * @var       Searches log table
    * @since       2.3.3
    */
    public $log_table = null;

    /**
    * @var       Search instance
    * @since       2.3.3
    */
    public $search = null;

    /**
     * returns plugin instance
     *
     * @access      public
     * @since       2.1.1
     * @return      self::$instance
     */
    public static function instance() {
				
        if ( is_null( self::$instance ) ) {
            self::$instance = new self();									
        }

        return self::$instance;
    }
			
	/**
	 * Class Constructor.
	 */
	public function __construct() {				
		add_action( 'init', array( $this, 'init' ), 2 );			
	}
			
	/**
     * Inititalizes everything
     *
     * @access      public
     * @since       2.2.7
     * @return      string
     */
    public function init() {
        
        global $wpdb;
        
        //Set the path and url to the includes folder
		$this->includes_path = plugin_dir_path( __FILE__ );
        $this->includes_url  = plugins_url( '/', __FILE__ );
        
        $this->log_table = $wpdb->prefix . "als_log";
        
        //Include the stemming library
        require_once( $this->includes_path . 'porter-stemmer.php'    );

        //Include core functions
        require_once( $this->includes_path . 'functions.php'    );

        //Include main search class
        require_once( $this->includes_path . 'class-als-search.php'    );
        $this->search = new Als_Search();

        //Include filter hooks
        require_once( $this->includes_path . 'filters.php'    );

        //Include action hooks
        require_once( $this->includes_path . 'actions.php'    );
        
        //Include the settings api
		require_once( $this->includes_path . 'admin/settings.php'    );
				
    }

} 

//A helper function to quickly access the class instance
function als_lite_instance(){
    return ALS_Lite::instance();
}

//Off we go
als_lite_instance();

